# Panorama Project

This project is initially intended to insert sercurity post rules into Panorama via API.  
The project may then be expanded further. Depending on future requirements.

## Run

### Docker

```
docker run -it -p 8888:8888 bnstimo/panorama_tool
```

### Python

#### Change directory to the project:

````
cd /path/to/project
````

#### Check python version (The version should be 3.11, but you can try it with other versions):

```
python --version
# or
python3 --version
```

#### Create a python venv:

```
python -m venv venv
# or
python3 -m venv venv
```

#### Activate the venv:

##### macOS / Linux

```
source venv/bin/activate
```

##### Windows

```
# In cmd.exe
venv\Scripts\activate.bat

# In PowerShell
venv\Scripts\Activate.ps1
```

#### Install requirements

```
pip install -r requirements.txt
```

#### Start flask

```
python -m flask run
# or optional --host=<ip> and/or --port=<port>
python -m flask run --host=0.0.0.0 --port=8888
```